@@ -27,48 +27,51 @@
 namespace kt
 {
 
-    class DBusTorrent;
+class DBusTorrent;
 
-    /**
-     * DBus interface to a TorrentFileStream
-     */
-    class DBusTorrentFileStream : public QObject
+/**
+ * DBus interface to a TorrentFileStream
+ */
+class DBusTorrentFileStream : public QObject
+{
+    Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.ktorrent.torrentfilestream")
+public:
+    DBusTorrentFileStream(bt::Uint32 file_index, DBusTorrent* tor);
+    ~DBusTorrentFileStream() override;
+
+    /// Was the stream created properly ?
+    bool ok() const
     {
-        Q_OBJECT
-        Q_CLASSINFO("D-Bus Interface", "org.ktorrent.torrentfilestream")
-    public:
-        DBusTorrentFileStream(bt::Uint32 file_index, DBusTorrent* tor);
-        ~DBusTorrentFileStream() override;
+        return !stream.isNull();
+    }
 
-        /// Was the stream created properly ?
-        bool ok() const {return !stream.isNull();}
+public Q_SLOTS:
+    /// Get the current stream position
+    Q_SCRIPTABLE qint64 pos() const;
 
-    public Q_SLOTS:
-        /// Get the current stream position
-        Q_SCRIPTABLE qint64 pos() const;
+    /// Get the total size
+    Q_SCRIPTABLE qint64 size() const;
 
-        /// Get the total size
-        Q_SCRIPTABLE qint64 size() const;
+    /// Seek, will fail if attempting to seek to a point which is not downloaded yet
+    Q_SCRIPTABLE bool seek(qint64 pos);
 
-        /// Seek, will fail if attempting to seek to a point which is not downloaded yet
-        Q_SCRIPTABLE bool seek(qint64 pos);
+    /// How many bytes are there available
+    Q_SCRIPTABLE qint64 bytesAvailable() const;
 
-        /// How many bytes are there available
-        Q_SCRIPTABLE qint64 bytesAvailable() const;
+    /// Get the path of the file
+    Q_SCRIPTABLE QString path() const;
 
-        /// Get the path of the file
-        Q_SCRIPTABLE QString path() const;
+    /// Get the current chunk relative to the first chunk of the file
+    Q_SCRIPTABLE bt::Uint32 currentChunk() const;
 
-        /// Get the current chunk relative to the first chunk of the file
-        Q_SCRIPTABLE bt::Uint32 currentChunk() const;
+    /// Read maxlen bytes from the stream
+    Q_SCRIPTABLE QByteArray read(qint64 maxlen);
 
-        /// Read maxlen bytes from the stream
-        Q_SCRIPTABLE QByteArray read(qint64 maxlen);
-
-    private:
-        DBusTorrent* tor;
-        bt::TorrentFileStream::Ptr stream;
-    };
+private:
+    DBusTorrent* tor;
+    bt::TorrentFileStream::Ptr stream;
+};
 
 }
 
