@@ -30,64 +30,63 @@
 
 namespace kt
 {
-    class GeoIPManager;
+class GeoIPManager;
+
+/**
+    @author Joris Guisson
+    Model for the PeerView
+*/
+class PeerViewModel : public QAbstractTableModel
+{
+    Q_OBJECT
+public:
+    PeerViewModel(QObject* parent);
+    ~PeerViewModel() override;
+
+    /// A peer has been added
+    void peerAdded(bt::PeerInterface* peer);
+
+    /// A peer has been removed
+    void peerRemoved(bt::PeerInterface* peer);
 
     /**
-        @author Joris Guisson
-        Model for the PeerView
+     * Update the model
+     */
+    void update();
+
+    /**
+        Clear the model
     */
-    class PeerViewModel : public QAbstractTableModel
-    {
-        Q_OBJECT
-    public:
-        PeerViewModel(QObject* parent);
-        ~PeerViewModel() override;
+    void clear();
 
-        /// A peer has been added
-        void peerAdded(bt::PeerInterface* peer);
+    int rowCount(const QModelIndex& parent) const override;
+    int columnCount(const QModelIndex& parent) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    QVariant data(const QModelIndex& index, int role) const override;
+    bool removeRows(int row, int count, const QModelIndex& parent) override;
+    bool insertRows(int row, int count, const QModelIndex& parent) override;
+    QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const override;
 
-        /// A peer has been removed
-        void peerRemoved(bt::PeerInterface* peer);
+    bt::PeerInterface* indexToPeer(const QModelIndex& idx);
 
-        /**
-         * Update the model
-         */
-        void update();
+public:
+    struct Item {
+        bt::PeerInterface* peer;
+        mutable bt::PeerInterface::Stats stats;
+        QString country;
+        QIcon flag;
 
-        /**
-            Clear the model
-        */
-        void clear();
+        Item(bt::PeerInterface* peer, GeoIPManager* geo_ip);
 
-        int rowCount(const QModelIndex& parent) const override;
-        int columnCount(const QModelIndex& parent) const override;
-        QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
-        QVariant data(const QModelIndex& index, int role) const override;
-        bool removeRows(int row, int count, const QModelIndex& parent) override;
-        bool insertRows(int row, int count, const QModelIndex& parent) override;
-        QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const override;
-
-        bt::PeerInterface* indexToPeer(const QModelIndex& idx);
-
-    public:
-        struct Item
-        {
-            bt::PeerInterface* peer;
-            mutable bt::PeerInterface::Stats stats;
-            QString country;
-            QIcon flag;
-
-            Item(bt::PeerInterface* peer, GeoIPManager* geo_ip);
-
-            bool changed() const;
-            QVariant data(int col) const;
-            QVariant decoration(int col) const;
-            QVariant sortData(int col) const;
-        };
-    private:
-        QVector<Item*> items;
-        GeoIPManager* geo_ip;
+        bool changed() const;
+        QVariant data(int col) const;
+        QVariant decoration(int col) const;
+        QVariant sortData(int col) const;
     };
+private:
+    QVector<Item*> items;
+    GeoIPManager* geo_ip;
+};
 
 }
 
