@@ -28,10 +28,10 @@ class MagnetUrlSchemeHandler : public QWebEngineUrlSchemeHandler
     Q_OBJECT
 
 public:
-    explicit MagnetUrlSchemeHandler(QObject *parent = nullptr );
-    void requestStarted(QWebEngineUrlRequestJob *request);
+    explicit MagnetUrlSchemeHandler(QObject *parent = nullptr);
+    void requestStarted(QWebEngineUrlRequestJob *request) override;
 
-signals:
+Q_SIGNALS:
     void magnetUrlDetected(const QUrl &url);
 
 };
